@@ -1,5 +1,5 @@
 from chessdotcom.errors import ChessDotComError
-from chessdotcom.caller import *
+from chessdotcom.client import *
 from chessdotcom.response import ChessDotComResponse
 
 
